@@ -62,7 +62,7 @@ mod tests {
 
     expand("example/benchmark.yml", doc, &mut benchmark);
 
-    assert_eq!(is_that_you(doc), true);
+    assert!(is_that_you(doc));
     assert_eq!(benchmark.len(), 2);
   }
 
@@ -75,7 +75,7 @@ mod tests {
 
     expand("example/benchmark.yml", doc, &mut benchmark);
 
-    assert_eq!(is_that_you(doc), true);
+    assert!(is_that_you(doc));
     assert_eq!(benchmark.len(), 2);
   }
 
@@ -88,7 +88,7 @@ mod tests {
 
     expand("example/benchmark.yml", doc, &mut benchmark);
 
-    assert_eq!(is_that_you(doc), true);
+    assert!(is_that_you(doc));
     assert_eq!(benchmark.len(), 1);
   }
 
